==> open-cluster-management-policy-model-6.7.2-sources.jar: io/fabric8/openclustermanagement/api/model/governancepolicypropagator/policy/v1beta1/AutomationDefBuilder.java <==
package io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class AutomationDefBuilder extends AutomationDefFluentImpl<AutomationDefBuilder> implements VisitableBuilder<AutomationDef,AutomationDefBuilder>{
  public AutomationDefBuilder() {
    this(false);
  }
  public AutomationDefBuilder(Boolean validationEnabled) {
    this(new AutomationDef(), validationEnabled);
  }
  public AutomationDefBuilder(AutomationDefFluent<?> fluent) {
    this(fluent, false);
  }
  public AutomationDefBuilder(AutomationDefFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new AutomationDef(), validationEnabled);
  }
  public AutomationDefBuilder(AutomationDefFluent<?> fluent,AutomationDef instance) {
    this(fluent, instance, false);
  }
  public AutomationDefBuilder(AutomationDefFluent<?> fluent,AutomationDef instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withExtraVars(instance.getExtraVars());
      fluent.withName(instance.getName());
      fluent.withSecret(instance.getSecret());
      fluent.withType(instance.getType());
    }
    this.validationEnabled = validationEnabled; 
  }
  public AutomationDefBuilder(AutomationDef instance) {
    this(instance,false);
  }
  public AutomationDefBuilder(AutomationDef instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withExtraVars(instance.getExtraVars());
      this.withName(instance.getName());
      this.withSecret(instance.getSecret());
      this.withType(instance.getType());
    }
    this.validationEnabled = validationEnabled; 
  }
  AutomationDefFluent<?> fluent;
  Boolean validationEnabled;
  public AutomationDef build() {
    AutomationDef buildable = new AutomationDef(fluent.getExtraVars(),fluent.getName(),fluent.getSecret(),fluent.getType());
    return buildable;
  }
  
}

==> open-cluster-management-policy-model-6.8.0-sources.jar: io/fabric8/openclustermanagement/api/model/governancepolicypropagator/policy/v1beta1/AutomationDefBuilder.java <==
package io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class AutomationDefBuilder extends AutomationDefFluent<AutomationDefBuilder> implements VisitableBuilder<AutomationDef,AutomationDefBuilder>{
  public AutomationDefBuilder() {
    this(false);
  }
  public AutomationDefBuilder(Boolean validationEnabled) {
    this(new AutomationDef(), validationEnabled);
  }
  public AutomationDefBuilder(AutomationDefFluent<?> fluent) {
    this(fluent, false);
  }
  public AutomationDefBuilder(AutomationDefFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new AutomationDef(), validationEnabled);
  }
  public AutomationDefBuilder(AutomationDefFluent<?> fluent,AutomationDef instance) {
    this(fluent, instance, false);
  }
  public AutomationDefBuilder(AutomationDefFluent<?> fluent,AutomationDef instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new AutomationDef());

    if (instance != null) {
      fluent.withExtraVars(instance.getExtraVars());
      fluent.withName(instance.getName());
      fluent.withSecret(instance.getSecret());
      fluent.withType(instance.getType());
      fluent.withExtraVars(instance.getExtraVars());
      fluent.withName(instance.getName());
      fluent.withSecret(instance.getSecret());
      fluent.withType(instance.getType());
    }
    this.validationEnabled = validationEnabled; 
  }
  public AutomationDefBuilder(AutomationDef instance) {
    this(instance,false);
  }
  public AutomationDefBuilder(AutomationDef instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new AutomationDef());

    if (instance != null) {
      this.withExtraVars(instance.getExtraVars());
      this.withName(instance.getName());
      this.withSecret(instance.getSecret());
      this.withType(instance.getType());
      this.withExtraVars(instance.getExtraVars());
      this.withName(instance.getName());
      this.withSecret(instance.getSecret());
      this.withType(instance.getType());
    }
    this.validationEnabled = validationEnabled; 
  }
  AutomationDefFluent<?> fluent;
  Boolean validationEnabled;
  public AutomationDef build() {
    AutomationDef buildable = new AutomationDef(fluent.getExtraVars(),fluent.getName(),fluent.getSecret(),fluent.getType());
    return buildable;
  }
  
}
